@@ -14,29 +14,10 @@ use NewsExtractor::Types qw(is_NewspaperName);
 use Importer 'NewsExtractor::TextUtil'  => qw( normalize_whitespace html2text );
 use Importer 'NewsExtractor::Constants' => qw( %RE );
 
-has site_name => (
-    is => "lazy",
-    isa => Maybe[Str],
-);
-
-has content_text => (
-    is => "lazy",
-    isa => Maybe[Str],
-);
+with 'NewsExtractor::Role::ContentTextExtractor';
 
 no Moo;
 
-sub _build_site_name {
-    my ($self) = @_;
-
-    my $el = $self->dom->at("meta[property='og:site_name']");
-    if ($el) {
-        return $el->attr('content');
-    }
-
-    return undef;
-}
-
 sub headline {
     my ($self) = @_;
 
@@ -97,9 +78,6 @@ sub dateline {
     elsif ($guess = $dom->at(".content .writer span:nth-child(2)")) {
         ($dateline) = $guess->text =~ m#([0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2})#;
     }
-    elsif ($guess = $dom->at("div.contentBox div.content_date")) {
-        ($dateline) = $guess->text =~ m#([0-9]{4}\.[0-9]{2}\.[0-9]{2} \| [0-9]{2}:[0-9]{2})#;
-    }
     elsif ($guess = $dom->at("div.content-wrapper-right > div > div > div:nth-child(4), span.f12_15a_g2")) {
         ($dateline) = $guess->text =~ m#([0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2})#;
     }
@@ -231,37 +209,4 @@ sub journalist {
     return $ret;
 }
 
-sub _build_content_text {
-    my ($self) = @_;
-    my ($el, $html);
-
-    # Cleanup some noisy elements that are known to interfere.
-    $self->dom->find('script, style, p.appE1121, div.sexmask, div.cat-list, div#marquee, #setting_weather')->map('remove');
-
-    my $extractor = HTML::ExtractContent->new;
-    if ($el = $self->dom->at('article')) {
-        $html = $extractor->extract("$el")->as_html;
-    } else {
-        $html = $extractor->extract( $self->dom->to_string )->as_html;
-    }
-
-    my $text = html2text( $html );
-
-    my @paragraphs = split(/\n\n/, $text) or return undef;
-
-    if (my $site_name = $self->site_name) {
-        $paragraphs[-1] =~ s/\A \s* \p{Punct}? \s* ${site_name} \s* \p{Punct}? \s* \z//x;
-        $paragraphs[-1] =~ s/${site_name}//x;
-    }
-
-    $paragraphs[-1] =~ s/\A \s* \p{Punct}? \s* $RE{newspaper_names} \s* \p{Punct}? \s* \z//x;
-
-    if (max( map { length($_) } @paragraphs ) < 30) {
-        # err "[$$] Not enough contents";
-        return undef;
-    }
-
-    return join "\n\n", @paragraphs;
-}
-
 1;
